RAFT-DASK-CU11
==============

**WARNING:** This project is not functional and is a placeholder from NVIDIA.
To install, please execute the following:

.. code-block:: bash

    pip install --extra-index-url https://pypi.nvidia.com raft-dask-cu11
